﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace TBmemo
{
    public partial class Form1 : Form
    {
        string filePath = null;
        SearchDialogBox sdb = null;
                
        
        public enum SearRepMode { Search, Replace };
        
        public Form1()
        {
            InitializeComponent();
        }

        #region File Menu Methods

        private void 終了ToolStripMenuItem_Click(object sender, EventArgs e)
        {           
                this.Close();
        }

        private void 名前を付けて保存ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            saveFileDialog1.ShowDialog();            
        }

        private void saveFileDialog1_FileOk(object sender, CancelEventArgs e)
        {
            try
            {
                filePath = saveFileDialog1.FileName;
                File.WriteAllText(filePath, textBox1.Text, Encoding.Default);
                textBox1.Modified = false;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "エラー", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void 開くToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            bool b = DeleteTextAnnounce();

            if(b)
                openFileDialog1.ShowDialog();
        }

        private void openFileDialog1_FileOk(object sender, CancelEventArgs e)
        {
            try
            {
                filePath = openFileDialog1.FileName;
                textBox1.Text = File.ReadAllText(openFileDialog1.FileName, Encoding.Default);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "エラー", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void textBox1_ModifiedChange(object sender, EventArgs e)
        {
            if (textBox1.Modified == true)
                上書き保存ToolStripMenuItem.Enabled = true;
            else
                上書き保存ToolStripMenuItem.Enabled = false;
        }

        private void 上書き保存ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (filePath != null)
            {
                try
                {
                    File.WriteAllText(filePath, textBox1.Text, Encoding.Default);
                    textBox1.Modified = false;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString(), "エラー", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            else
                saveFileDialog1.ShowDialog();
        }

        private void 新規ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            bool b = DeleteTextAnnounce();
            if (b)
            {
                textBox1.Clear();
                textBox1.Modified = false;
                filePath = null;
            }           
        }

        private bool DeleteTextAnnounce()
        {
            if (textBox1.Modified)
            {
                DialogResult result;
                string msg = "変更内容は保存されていません。破棄してよろしいでしょうか？";
                result = MessageBox.Show(msg, "警告", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation);
                if (result == DialogResult.Yes)
                    return true;
                else
                    return false;
            }
            else            
                return true;
            
        }

        private void form1_FromClosing(object sender, FormClosingEventArgs e)
        {
            bool b = DeleteTextAnnounce();
            if(!b)
                e.Cancel = true;
        }

        #endregion

        #region Edit Menu Methods

        private void 切り取りToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if(textBox1.SelectionLength > 0)
                textBox1.Cut();
        }

        private void コピーCToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (textBox1.SelectionLength > 0)
                textBox1.Copy();
        }

        private void すべて選択AToolStripMenuItem_Click(object sender, EventArgs e)
        {
            textBox1.SelectAll();            
        }

        private void 元に戻すToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (textBox1.CanUndo)
            {
                textBox1.Undo();
                textBox1.ClearUndo();
            }
        }

        private void 貼り付けPToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (Clipboard.GetDataObject().GetDataPresent(DataFormats.Text))
                textBox1.Paste();
        }

        private void 検索ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (sdb == null || sdb.IsDisposed)
            {
                sdb = new SearchDialogBox(SearRepMode.Search, textBox1);
                this.AddOwnedForm(sdb);
                sdb.Show();
            }
        }

        private void 置換RToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (sdb == null || sdb.IsDisposed)
            {
                sdb = new SearchDialogBox(SearRepMode.Replace, textBox1);
                this.AddOwnedForm(sdb);
                sdb.Show();
            }
        }

        #endregion

        private void TopMostToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.TopMost = !this.TopMost;
        }

        private void WordWrapToolStripMenuItem_Click(object sender, EventArgs e)
        {
            textBox1.WordWrap = !textBox1.WordWrap;
        }

        private void FontToolStripMenuItem_Click(object sender, EventArgs e)
        {
            DialogResult dr = fontDialog1.ShowDialog();

            if (dr == DialogResult.OK)
            {
                textBox1.Font = fontDialog1.Font;
            }
        }

        private void statusbarToolStripMenuItem_Click(object sender, EventArgs e)
        {
            statusStrip1.Visible = !statusStrip1.Visible;

            if (statusStrip1.Visible)
            {
                textBox1.Size = new Size(textBox1.Width, textBox1.Height - 23);
                textBox1.Dock = DockStyle.None;
                textBox1.Anchor = (AnchorStyles.Bottom | AnchorStyles.Left |
                    AnchorStyles.Right | AnchorStyles.Top);
            }
            else
            {
                textBox1.Dock = DockStyle.Fill;
            }
        }        

    }
}
